package pack_multieditor_observer;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JTextArea;

public class MultiEditor implements Observer {
	JButton openButton;
	JPanel mainPanel;
	JTextArea textArea;
	Document editedText;

	public MultiEditor(){
		this(new Document());
	}

	MultiEditor(Document editedText){
		this.editedText = editedText;
		editedText.attach(this);	
		buildUI();
		buildButtonListener();
		buildTextAreaListener();
		update();
	}

	private void buildTextAreaListener() {
		textArea.addKeyListener(new KeyListener() { // anonymous inner class implementing KeyListener
													// has access to members of this (e.g. textArea)
			public void keyReleased(KeyEvent e) {
				editedText.setText(textArea.getText());
			}
			
			public void keyTyped(KeyEvent e) {/*do nothing*/ }
			public void keyPressed(KeyEvent e) { /*do nothing*/ }
		});
	}

	private void buildButtonListener() {
		openButton.addActionListener(
				new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				new MultiEditor(editedText);
			}
		});
	}

	private void buildUI() {
		JFrame frame = new JFrame("Paint");
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		mainPanel = new JPanel(new BorderLayout());
		textArea = new JTextArea(80,80);
		openButton = new JButton("Open");
		mainPanel.add(openButton, BorderLayout.SOUTH);
		mainPanel.add(textArea, BorderLayout.CENTER);
		frame.getContentPane().add(mainPanel);
		frame.setSize(640,480);
		frame.setVisible(true);
	}

	public void update() {
		String editedString = editedText.getText();
		if(!editedString.equals(textArea.getText())) {
			this.textArea.setText(editedString);
		}
		
	}

	public static void main(String[] args) {
		new MultiEditor();
	}
}

